import { ValidationResult } from './validation-result';
export * from './validation-result';
export declare type Validator<T> = {
    [key in keyof T]: (arg: any) => ValidationResult<T[key]>;
};
export declare type Validated<T> = {
    [key in keyof T]: T[key];
};
export interface ILength {
    length: number;
}
export interface IValidationOptions {
    allowAdditionalProperties?: boolean;
}
export declare function validate<T>(arg: any, assertion: (arg: any) => ValidationResult<T>): ValidationResult<T>;
export declare function extendValidator<T, U>(validator1: Validator<T>, validator2: Validator<U>): Validator<T & U>;
export declare function conformsTo<T>(validator: Validator<T>): (arg: any) => ValidationResult<Validated<T>>;
export declare function conformsTo<T>(validator: Validator<T>, options: IValidationOptions): (arg: any) => ValidationResult<Validated<T>>;
export declare function conformsTo<T, U>(validator: Validator<T>, next: (arg: Validated<T>) => ValidationResult<U>): (arg: any) => ValidationResult<U>;
export declare function conformsTo<T, U>(validator: Validator<T>, options: IValidationOptions, next: (arg: Validated<T>) => ValidationResult<U>): (arg: any) => ValidationResult<U>;
export declare function optional<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T | undefined>;
export declare function nullable<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T | null>;
export declare function defaultsTo(def: any): (arg: any) => ValidationResult<any>;
export declare function defaultsTo<T>(def: T, next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function onErrorDefaultsTo<T, U>(def: U, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function isBoolean(): (arg: any) => ValidationResult<boolean>;
export declare function isBoolean<T = boolean>(next: (arg: boolean) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function isNumber(): (arg: any) => ValidationResult<number>;
export declare function isNumber<T = number>(next: (arg: number) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function min(min: number): (arg: number) => ValidationResult<number>;
export declare function min<T = number>(min: number, next: (arg: number) => ValidationResult<T>): (arg: number) => ValidationResult<T>;
export declare function max(max: number): (arg: number) => ValidationResult<number>;
export declare function max<T = number>(max: number, next: (arg: number) => ValidationResult<T>): (arg: number) => ValidationResult<T>;
export declare function isString(): (arg: any) => ValidationResult<string>;
export declare function isString<T = string>(next: (arg: string) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function matches(regex: RegExp): (arg: string) => ValidationResult<string>;
export declare function matches<T = string>(regex: RegExp, next: (arg: string) => ValidationResult<T>): (arg: string) => ValidationResult<T>;
export declare function minLength<T extends ILength>(min: number): (arg: T) => ValidationResult<T>;
export declare function minLength<T extends ILength, U = T>(min: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function maxLength<T extends ILength>(max: number): (arg: T) => ValidationResult<T>;
export declare function maxLength<T extends ILength, U = T>(max: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function lengthIs<T extends ILength>(length: number): (arg: T) => ValidationResult<T>;
export declare function lengthIs<T extends ILength, U = T>(length: number, next: (arg: T) => ValidationResult<U>): (arg: T) => ValidationResult<U>;
export declare function isArray(): (arg: any) => ValidationResult<any[]>;
export declare function isArray<T>(next: (arg: any[]) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function eachItem<T>(assertion: (arg: any) => ValidationResult<T>): (arg: any[]) => ValidationResult<T[]>;
export declare function eachItem<T, U>(assertion: (arg: any) => ValidationResult<T>, next: (arg: T[]) => ValidationResult<U>): (arg: any[]) => ValidationResult<U>;
export declare function isObject(): (arg: any) => ValidationResult<any>;
export declare function isObject<T>(next: (arg: any) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function equals<T>(value: T, ...values: T[]): (arg: any) => ValidationResult<T>;
export declare function isMap(): (arg: any) => ValidationResult<{
    [key: string]: any;
}>;
export declare function isMap<T>(next: (arg: {
    [key: string]: any;
}) => ValidationResult<T>): (arg: any) => ValidationResult<T>;
export declare function eachValue<T>(assertion: (arg: any) => ValidationResult<T>): (arg: {
    [key: string]: any;
}) => ValidationResult<{
    [key: string]: T;
}>;
export declare function eachValue<T, U>(assertion: (arg: any) => ValidationResult<T>, next: (arg: {
    [key: string]: T;
}) => ValidationResult<U>): (arg: {
    [key: string]: any;
}) => ValidationResult<U>;
